pub enum TomeCommands {
CommandHelp(HelpArgs),
CommandComplete(CompleteArgs),
CommandExecute(ExecuteArgs),
Init(InitArgs),
Run(RunArgs),
}Variants
CommandHelp(HelpArgs)
CommandComplete(CompleteArgs)
CommandExecute(ExecuteArgs)
Init(InitArgs)
Run(RunArgs)
find a script and exec it. run will not run the script in completion mode, regardless of the script front matter. builtins such as help are not accessible via this command