pub struct InitArgs {
pub command_name: String,
pub command_directory_path: String,
pub shell_type_or_path: String,
}Fields
command_name: StringThe name for the generated command.
command_directory_path: StringThe path to the directory that contains the commands to load.
shell_type_or_path: StringThe type of the shell to use, or the path to the shell executable being used.