Structs
- Script
- Any executable script can be added to be executed, but It’s possible to add metadata to the script via comments as well.
Functions
- is_
source_ file - is_
tome_ script - quote_
for_ shell - resolve_
source_ path - Try to resolve a path that may have a
.sourceextension on disk. Returns the resolved path if found, or None. - strip_
source_ suffix