Script

Struct Script 

pub struct Script {
    pub help_string: String,
    pub path: String,
    pub should_source: bool,
    pub should_complete: bool,
    pub summary_string: String,
}
Any executable script can be added to be executed, but It’s possible to add metadata to the script via comments as well.

Fields

help_string: Stringpath: String

the string that should be used for usage information the path the script is located at.

should_source: bool

determines if the script should be sourced or not.

should_complete: bool

determines if the script should have completion invoked or not.

summary_string: String

the string that should be printed when help is requested.

Implementations

Source

impl Script

pub fn load(path: &str) -> Result<Script>

pub fn load_from_buffer(path: String, body: Box<dyn Read>) -> Script

pub fn get_execution_body( &self, command_type: CommandType, shell: &str, args: &[&String], ) -> Result<String, String>