get_shell_type

Function get_shell_type 

pub fn get_shell_type(shell_executable_path: &str) -> Result<ShellType, String>
Determine the shell type from the shell_executable_path passed.

If no string is passed, attempt to infer the information from the “SHELL” environment variable.

This function is designed to infer the shell from a variety of architectures and operating systems.