Module script

Module script 

Structs

Script
Any executable script can be added to be executed, but It’s possible to add metadata to the script via comments as well.

Functions

is_source_file
is_tome_script
quote_for_shell
resolve_source_path
Try to resolve a path that may have a .source extension on disk. Returns the resolved path if found, or None.
strip_source_suffix