pub struct Script {
pub help_string: String,
pub path: String,
pub should_source: bool,
pub should_complete: bool,
pub summary_string: String,
}Expand description
Any executable script can be added to be executed, but It’s possible to add metadata to the script via comments as well.
Fields
help_string: Stringpath: Stringthe string that should be used for usage information the path the script is located at.
should_source: booldetermines if the script should be sourced or not.
should_complete: booldetermines if the script should have completion invoked or not.
summary_string: Stringthe string that should be printed when help is requested.
Implementations